Crate vortex_session

Crate vortex_session 

Modules

registry

Structs

ArcSwapMap
A concurrent HashMap backed by an ArcSwap, offering lock-free reads and copy-on-write writes.
SessionGuard
A reference to a session variable of type V, returned by SessionExt::get and SessionExt::get_opt.
SessionMut
A copy-on-write mutable handle to a session variable of type V, returned by SessionExt::get_mut.
VortexSession
A Vortex session encapsulates the set of extensible arrays, layouts, compute functions, dtypes, etc. that are available for use in a given context.

Traits

SessionExt
Trait for accessing the state of a Vortex session.
SessionVar
This trait defines variables that can be stored against a Vortex session.
VortexSessionVar
A SessionVar that can be stored in a VortexSession.