Module registry

Module registry 

Many session types use a registry of objects that can be looked up by name to construct contexts. This module provides a generic registry type for that purpose.

Structs

CachedId
A lazily-initialized, cached Id for use as a static.
Context
A Context holds a set of interned IDs for use during serialization/deserialization, mapping IDs to u16 indices.
Id
A lightweight, copyable identifier backed by a global string interner.
ReadContext
A ReadContext holds a set of interned IDs for use during deserialization, mapping u16 indices to IDs.
Registry
A registry of items that are keyed by a string identifier.