Context

Struct Context 

pub struct Context { /* private fields */ }
A Context holds a set of interned IDs for use during serialization/deserialization, mapping IDs to u16 indices.

Upcoming Changes

  1. This object holds an Arc of RwLock internally because we need concurrent access from the layout writer code path. We should update SegmentSink to take an Array rather than ByteBuffer such that serializing arrays is done sequentially.
  2. The name is terrible. Interner is better, but I want to minimize breakage for now.

Implementations

Source

impl Context

pub fn new(ids: Vec<Id>) -> Self

Create a context with the given initial IDs.

pub fn empty() -> Self

Create an empty context.

pub fn with_valid_ids(self, ids: impl IntoIterator<Item = Id>) -> Self

Restrict the permissible set of interned IDs.

pub fn intern(&self, id: &Id) -> Option<u16>

Intern an ID, returning its index.

pub fn to_ids(&self) -> Vec<Id>

Get the list of interned IDs.