Modules
Structs
- ArcSwap
Map - A concurrent
HashMapbacked by anArcSwap, offering lock-free reads and copy-on-write writes. - Session
Guard - A reference to a session variable of type
V, returned bySessionExt::getandSessionExt::get_opt. - Session
Mut - A copy-on-write mutable handle to a session variable of type
V, returned bySessionExt::get_mut. - Vortex
Session - A Vortex session encapsulates the set of extensible arrays, layouts, compute functions, dtypes, etc. that are available for use in a given context.
Traits
- Session
Ext - Trait for accessing the state of a Vortex session.
- Session
Var - This trait defines variables that can be stored against a Vortex session.
- Vortex
Session Var - A
SessionVarthat can be stored in aVortexSession.