Many session types use a registry of objects that can be looked up by name to construct contexts. This module provides a generic registry type for that purpose.
Structs
- Cached
Id - A lazily-initialized, cached
Idfor use as astatic. - Context
- A
Contextholds a set of interned IDs for use during serialization/deserialization, mapping IDs to u16 indices. - Id
- A lightweight, copyable identifier backed by a global string interner.
- Read
Context - A
ReadContextholds a set of interned IDs for use during deserialization, mapping u16 indices to IDs. - Registry
- A registry of items that are keyed by a string identifier.