pub struct Context { /* private fields */ }Expand description
A Context holds a set of interned IDs for use during serialization/deserialization, mapping
IDs to u16 indices.
Upcoming Changes
- This object holds an Arc of RwLock internally because we need concurrent access from the layout writer code path. We should update SegmentSink to take an Array rather than ByteBuffer such that serializing arrays is done sequentially.
- The name is terrible.
Interneris better, but I want to minimize breakage for now.
Implementations
Sourceimpl Context
impl Context
Sourcepub fn with_valid_ids(self, ids: impl IntoIterator<Item = Id>) -> Self
pub fn with_valid_ids(self, ids: impl IntoIterator<Item = Id>) -> Self
Restrict the permissible set of interned IDs.