pub struct VortexSession(/* private fields */);Expand description
A Vortex session encapsulates the set of extensible arrays, layouts, compute functions, dtypes, etc. that are available for use in a given context.
It is also the entry-point passed to dynamic libraries to initialize Vortex plugins.
Implementations
Sourceimpl VortexSession
impl VortexSession
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Create a new VortexSession with no session state.
It is recommended to use the default() method instead provided by the main vortex crate.
Sourcepub fn with<V: SessionVar + Default>(self) -> Self
pub fn with<V: SessionVar + Default>(self) -> Self
Inserts a new session variable of type V with its default value.
Panics
If a variable of that type already exists.
Sourcepub fn with_some<V: SessionVar>(self, var: V) -> Self
pub fn with_some<V: SessionVar>(self, var: V) -> Self
Sourcepub fn allow_unknown(self) -> Self
pub fn allow_unknown(self) -> Self
Allow deserializing unknown plugin IDs as non-executable foreign placeholders.
Sourcepub fn allows_unknown(&self) -> bool
pub fn allows_unknown(&self) -> bool
Returns whether unknown plugins should deserialize as foreign placeholders.